YouTube uploader for Pyvo videos
================================

This package uploads recordings from `Pyvo`_ to YouTube using YouTube
API v3. It is based heavily on `Google example code`_. It reads video
metadata YAML files generated by Petr Viktorin’s `talk video maker`_.

Usage
-----

First, you need to authenticate with Google using OAuth 2.0. For that,
you need client secrets file. One is bundled, you can also make your
`own`_ in the Google `Developers Console`_.

During the first run, you’ll get prompted to authenticate to a YouTube
channel by opening a webpage in a browser and copying back a token.
Those credentials are then stored by default in
``~/.config/talk-video-uploader/youtube_credentials.json``.

To upload videos, create a YAML file with metadata for each video file
and give path to those files as arguments to ``talk-video-uploader``.

YAML metadata example
---------------------

.. code-block:: yaml

   fname: Videofile.mkv
   date: 2018-01-01
   event: Ostravské Pyvo
   url: https://pyvo.cz/ostrava-pyvo/2018-01/
   lightning: true
   speaker: Jan Novák
   title: Interesting topic
   tags:
     - Python
     - Pyvo
     - Something
   language:
     audio: cs

.. _Pyvo: https://pyvo.cz
.. _Google example code: https://developers.google.com/youtube/v3/docs/videos/insert#examples
.. _talk video maker: https://github.com/encukou/talk-video-maker
.. _own: https://developers.google.com/youtube/registering_an_application
.. _Developers Console: https://console.developers.google.com/
